@@ -23,9 +23,10 @@
       READ(*,*) IWS
 
       CALL GROPN(IWS)
+
       CALL GRFRM
       CALL GRSWND(-1., 1., -1., 1.)
-      CALL GRSVPT(.1, .9, .1, .9)
+      CALL GRSVPT(.125, .875, .2, .95)
       CALL GRSTRN(1)
       CALL GRSTRF
 
@@ -36,6 +37,11 @@
       CALL UYAXDV('L', .1, .5)
       CALL UYAXDV('R', .1, .5)
 
+      CALL USPSET("MXDGTX",5)
+      CALL UIQCRG(ZMIN, ZMAX)
+      CALL UIXBAR(0.3, 0.7, 0.1, 0.14, ZMIN, ZMAX, "B")
+      CALL UXSTTL("B","color scale",0.0)
+
       CALL GRCLS
 
       END
