@@ -21,7 +21,7 @@
 
       CALL GLRGET( 'RUNDEF', RUNDEF )
       CALL GRSWND( XMIN, XMAX, RUNDEF, RUNDEF )
-      CALL USSTTL( 'TIME', 'YEAR', 'HEAT FLUX', 'W/m\^2"' )
+      CALL USSTTL( 'TIME', 'YEAR', 'HEAT FLUX', 'W/m\^2' )
       CALL USGRPH( NMAX+1, RUNDEF, Y )
 
       CALL GRCLS
