@@ -1,8 +1,7 @@
 *-----------------------------------------------------------------------
 *     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
-      CHARACTER*3 FUNCTION USGI(IC)
-
+      CHARACTER(3) FUNCTION USGI(IC)
 
       USGI='\x'//CHAR(IC)
 
