@@ -490,13 +490,15 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
   GtkWidget *vbox;
 
   gtk_init(0,NULL);
-
+  if (drawing_area ==NULL){
 #if GTKVERSION==2
-  drw=gtk_drawing_area_new();
+    drw = gtk_drawing_area_new();
 #else
-  drw = (GtkWidget*)gtk_drawing_area_new();
+    drw = (GtkWidget*)gtk_drawing_area_new();
 #endif
-
+  }else{
+    drw = drawing_area;
+  }
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
 #if GTKVERSION==2
@@ -511,7 +513,7 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
 #if GTKVERSION==2
   gtk_container_add(GTK_CONTAINER (window), drw);
 #else
-  gtk_container_add(GTK_CONTAINER(window),drw);
+  gtk_container_add(GTK_CONTAINER (window),drw);
 #endif
   if (!wnd){
     gtk_widget_realize(drw);
@@ -528,7 +530,7 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
                           G_CALLBACK(zg_button_press_event), NULL);
 #endif
     }
-      gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
 #if GTKVERSION==2
     gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
     gtk_signal_connect(GTK_OBJECT (window), "button_press_event",
@@ -548,7 +550,7 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
     g_signal_connect(G_OBJECT (window), "destroy",
   	          	      G_CALLBACK(zg_destroy_event), NULL);
 #endif
-      gtk_widget_show(window);
+    gtk_widget_show(window);
   }
   return drw;
 }
@@ -587,6 +589,7 @@ static cairo_t *zgcsfc(){
       linewidth[8] = 14.0;
     }else if(ifl == IFL_PNG){
       csr = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,wsxwd,wsywd);
+      }
     }else if(ifl == IFL_SVG){
       if (page != 0){
         sprintf (cout, "%s_%0*d.svg", dmpfile,dmpdgt, page);
@@ -600,35 +603,15 @@ static cairo_t *zgcsfc(){
         sprintf (cout, "%s_%0*d.pdf", dmpfile,dmpdgt, page);
       }
       csr = cairo_pdf_surface_create(cout, PS_PAGE_WIDTH * ddvscale, PS_PAGE_HEIGHT * ddvscale );
-/*      linewidth[0] =  2.0;
-      linewidth[1] =  4.0;
-      linewidth[2] =  6.0;
-      linewidth[3] =  8.0;
-      linewidth[4] = 10.0;
-      linewidth[5] = 11.0;
-      linewidth[6] = 12.0;
-      linewidth[7] = 13.0;
-      linewidth[8] = 14.0; */
-/*      linewidth[0] =  1.0;
-      linewidth[1] =  2.0;
-      linewidth[2] =  2.0;
-      linewidth[3] =  3.0;
-      linewidth[4] = 3.0;
-      linewidth[5] = 4.0;
-      linewidth[6] = 4.0;
-      linewidth[7] = 5.0;
-      linewidth[8] = 5.0;*/
-    }
   }
 
   cro = cairo_create(csr);
 
   cairo_pattern_set_filter(cairo_get_source(cro), CAIRO_FILTER_NEAREST);
-
   cairo_set_source_rgb(cro,1.0,1.0,1.0);
 
   return cro;
-}
+ }
 
 /*-----------------------------------------------*/
 static void zgbmcv(int *nx, int *ny, char bmline[], char bitmap[])
@@ -768,18 +751,16 @@ void ZGDOPN(DCL_INT *dev_type,
   /* check drawing_area, if not set, stop */
 
   if (idev_type == IWS_DISP){
-    if (drawing_area == NULL) {
-      ldclonly = TRUE;
-      wsxwd  = iwidth  + 2 * PAD;  /* window width */
-      wsywd  = iheight + 2 * PAD;  /* window height */
-      wsxmnz = PAD + offx;                /* lower-left  corner */
-      wsymnz = PAD + offy;                /* lower-left  corner */
+    wsxwd  = iwidth  + 2 * PAD;  /* window width */
+    wsywd  = iheight + 2 * PAD;  /* window height */
+    wsxmnz = PAD + offx;                /* lower-left  corner */
+    wsymnz = PAD + offy;                /* lower-left  corner */
+    ldclonly = TRUE;
 #ifndef WINDOWS
-      drawing_area = zggdrw_(width,height);
+    drawing_area = zggdrw_(width,height);
 #else
-      drawing_area = ZGGDRW(width,height);
+    drawing_area = ZGGDRW(width,height);
 #endif
-    }
   }else if (idev_type == IWS_FILE){
     if(ifl == IFL_EPS || ifl == IFL_PDF){
     wsywd = iPS_PAGE_WIDTH * ddvscale;
@@ -1017,6 +998,7 @@ void ZGPCLS(void)
 #else
       zgupdate(0,cr);
       gtk_widget_queue_draw(drawing_area);
+      gtk_main_iteration();
 #endif
     }
     if (wait_np) {
@@ -2729,3 +2711,35 @@ static void zgcatl(){
     cairo_rotate(cr, -2 * 3.1415926 * 0.25 );
     cairo_translate (cr, -iPS_PAGE_HEIGHT * ddvscale / 2.0 , -iPS_PAGE_WIDTH * ddvscale / 2.0 );
 }
+
+
+#ifndef WINDOWS
+void zgsdrw_(d)
+#else
+void ZGSDRW(d)
+#endif
+     GtkWidget *d;
+{
+  /* set/reset drawing_area */
+  drawing_area = d;
+
+}
+
+#ifndef WINDOWS
+cairo_surface_t* zgqcsr_()
+#else
+cairo_surface_t* ZGQCSR()
+#endif
+{
+  return csr;
+}
+
+#ifndef WINDOWS
+void zgscsr_(csur)
+#else
+void ZGSCSR(csur)
+#endif
+    cairo_surface_t *csur;
+{
+  csr = csur;
+}
