@@ -123,7 +123,7 @@
         IF ((TUY.GE.TYMAX).OR.(TUY.LE.TYMIN))THEN
           LEXTEN=.TRUE.
         END IF
-        IF(LEXTEN.AND.(ITR.GT.5))THEN
+        IF(LEXTEN.AND.((ITR.GT.5).AND.(ITR.NE.51)))THEN
               IMAGE(I) = 0
         ELSE IF (IX.EQ.IUNDEF .OR. IY.EQ.IUNDEF) THEN
               IMAGE(I) = 0
