@@ -46,7 +46,7 @@
             TYMIN = CPR*ASIN(1./RSAT)
           END IF
         ELSE
-          TYMIN =  -CPD*90
+          TYMIN =  -CPD*90.
         END IF
       END IF
 
