@@ -1,8 +1,9 @@
 *-----------------------------------------------------------------------
 *     USINIT                                          DCL 5.0  95/09/04
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE USINIT
-      PARAMETER(OFFSET = 0.018)
 
       CALL GLRGET('RUNDEF', RUNDEF)
       CALL GLIGET('IUNDEF', IUNDEF)
@@ -13,6 +14,9 @@
 
 *-----------------------------------------------------------------------
 
+      CALl UZRGET( 'RSIZEL1',  SIZEL)
+      OFFSET = SIZEL*0.86
+
       CALL USRSET( 'SOFFXTR',  OFFSET)
       CALL USRSET( 'SOFFXBR',  OFFSET)
       CALL USRSET( 'SOFFXUR',  OFFSET)
