@@ -1,14 +1,7 @@
-/* dcl-5.3.2/src/math1/syslib/msgdmp.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
 #include "stdio.h"
-//#include "libtinyf2c.h"
 
 #define min(a,b) ((a) <= (b) ? (a) : (b))
 
-
 /* Table of constant values */
 typedef long int ftnlen;
 typedef char *address;
@@ -21,8 +14,6 @@ static integer c__4 = 4;
 static integer c__10 = 10;
 static integer memfailure = 3;
 
-// libtiny
-
 int xargc;
 char **xargv;
 char *F77_aloc(integer Len, char *whence);
@@ -294,141 +285,6 @@ static int msgdmp_err_replaceable(char *clev, char *csub, char *cmsg, int
     return 0;
 } /* msgdmp_err_replaceable */
 
-real rgngt__(real *rx)
-{
-    /* System generated locals */
-    real ret_val;
-
-    /* Local variables */
-    static integer ip;
-    static real bx;
-    extern /* Subroutine */ int gngt_(real *, real *, integer *);
-    extern real rexp_(real *, integer *, integer *);
-
-    gngt_(rx, &bx, &ip);
-    ret_val = rexp_(&bx, &c__10, &ip);
-    return ret_val;
-} /* rgngt_ */
-
-real rgnle__(real *rx)
-{
-    /* System generated locals */
-    real ret_val;
-
-    /* Local variables */
-    static integer ip;
-    static real bx;
-    extern /* Subroutine */ int gnle_(real *, real *, integer *);
-    extern real rexp_(real *, integer *, integer *);
-
-    gnle_(rx, &bx, &ip);
-    ret_val = rexp_(&bx, &c__10, &ip);
-    return ret_val;
-} /* rgnle_ */
-
-real rexp__(real *rx, integer *ib, integer *ie)
-{
-    /* System generated locals */
-    integer i__1;
-    real ret_val;
-
-    /* Local variables */
-    static integer i__;
-    extern /* Subroutine */ int msgdmp__(char *, char *, char *, ftnlen, 
-	    ftnlen, ftnlen);
-
-    if (*ib == 0) {
-	msgdmp__("E", "REXP  ", "IB .EQ. 0.", (ftnlen)1, (ftnlen)6, (ftnlen)10)
-		;
-    }
-    ret_val = *rx;
-    i__1 = abs(*ie);
-    for (i__ = 1; i__ <= i__1; ++i__) {
-	if (*ie > 0) {
-	    ret_val *= *ib;
-	} else {
-	    ret_val /= *ib;
-	}
-/* L10: */
-    }
-    return ret_val;
-} /* rexp_ */
-
-
-real rudlev__(integer *nlev)
-{
-    /* System generated locals */
-    integer i__1;
-    real ret_val;
-
-    /* Local variables */
-    static real hl1, hl2;
-    static char clv1[8], clv2[8];
-    static integer indx1, indx2;
-    static real zlev1, zlev2;
-    static integer ityp1, ityp2, nlevz;
-    extern /* Subroutine */ int udqcln__(integer *), msgdmp__(char *, char *, 
-	    char *, ftnlen, ftnlen, ftnlen), udqclv__(real *, integer *, 
-	    integer *, char *, real *, integer *, ftnlen);
-
-    udqcln_(&nlevz);
-    if (! (2 <= nlevz)) {
-	msgdmp__("W", "IUDLEV", "NO. OF CONTOUR LEVELS IS LESS THAN 2.", (
-		ftnlen)1, (ftnlen)6, (ftnlen)37);
-	ret_val = 0.f;
-	return ret_val;
-    }
-    if (! (1 <= *nlev && *nlev <= nlevz - 1)) {
-	msgdmp__("W", "IUDLEV", "NLEV IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, 
-		(ftnlen)21);
-	ret_val = 0.f;
-	return ret_val;
-    }
-    udqclv_(&zlev1, &indx1, &ityp1, clv1, &hl1, nlev, (ftnlen)8);
-    i__1 = *nlev + 1;
-    udqclv_(&zlev2, &indx2, &ityp2, clv2, &hl2, &i__1, (ftnlen)8);
-    ret_val = zlev2 - zlev1;
-    return ret_val;
-} /* rudlev_ */
-
-real rr2d__(real *x)
-{
-    /* System generated locals */
-    real ret_val;
-
-    /* Local variables */
-    extern real rfpi_(void);
-
-    ret_val = *x * 180 / rfpi_();
-    return ret_val;
-} /* rr2d_ */
-
-real rrms__(real *rx, integer *n, integer *jx)
-{
-    /* System generated locals */
-    real ret_val;
-
-    /* Local variables */
-    extern real rrms0_(real *, integer *, integer *), rrms1_(real *, integer *
-	    , integer *);
-    static logical lmiss;
-    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen);
-
-    /* Parameter adjustments */
-    --rx;
-
-    /* Function Body */
-    gllget_("LMISS", &lmiss, (ftnlen)5);
-    if (lmiss) {
-	ret_val = rrms1_(&rx[1], n, jx);
-    } else {
-	ret_val = rrms0_(&rx[1], n, jx);
-    }
-    return ret_val;
-} /* rrms_ */
-
-
-
 // tinyf2c
 /* stop the excution of the program up to the statement of s
  */
@@ -556,3 +412,4 @@ void exit_(integer *rc)
 {
 	exit(*rc);
 }
+
