@@ -1,7 +1,7 @@
 *-----------------------------------------------------------------------
 *     TMRQNP / TMRQID / TMRQCP / TMRQVL / TMRSVL
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2017 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2012 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE TMRQNP(NCP)
       IMPLICIT NONE
@@ -37,7 +37,7 @@
       DATA      LFIRST / .TRUE. /
 
       INTEGER   N, NCP
-      INTEGER   IDX, IP, INZ
+      INTEGER   IDX, IP, IN
       REAL      RPARA
 
       NCP = NPARA
@@ -112,16 +112,16 @@
 
       RETURN
 *-----------------------------------------------------------------------
-      ENTRY TMRQIN(CP, INZ)
+      ENTRY TMRQIN(CP, IN)
 
       DO 20 N = 1, NPARA
         IF (LCHREQ(CP, CPARAS(N)) .OR. LCHREQ(CP, CPARAL(N))) THEN
-          INZ = N
+          IN = N
           RETURN
         END IF
    20 CONTINUE
 
-      INZ = 0
+      IN = 0
 
       RETURN
       END
