@@ -62,6 +62,9 @@
       NYBOUND(1)=1
       NYBOUND(2)=NY
 
+      TRX(1:NX*NY,1:2)=0.0
+      TRY(1:NX*NY,1:2)=0.0
+      TOTNM(1:NX*NY,1:2)=0
       NM(1:NX*NY,1:2)=0
 
 *-- CHECKING VARYING DT
@@ -231,6 +234,9 @@
                               ELSE
                                  GO TO 163  !* äƤеո׻.
                               END IF
+                           ELSE  !* Ѱդۤή³ΰѤ
+                              TMPRX(1,1)=TMPRX(NX*NY,1)
+                              TMPRY(1,1)=TMPRY(NX*NY,1)
                            END IF
 
                            IF(K.EQ.NX*NY)THEN
@@ -243,9 +249,6 @@
                               CALL MSGDMP( 'W', 'TMSTLN', 
      &                                     'ARRAY WILL BE OVER FLOW.')
                               GO TO 100
-                           ELSE  !* Ѱդۤή³ΰѤ
-                              TMPRX(1,1)=TMPRX(NX*NY,1)
-                              TMPRY(1,1)=TMPRY(NX*NY,1)
                            END IF
 
  162                    CONTINUE
@@ -304,6 +307,9 @@
 *-- ήѰդʾϢ³, ǽޤǷ׻.
                            IF(NM(ICOUNTER-1,2).LT.NX*NY)THEN
                               GO TO 160  !* äƤмή׻
+                           ELSE  !* Ѱդۤή³ΰѤ
+                              TMPRX(1,2)=TMPX(NX*NY)
+                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
                            IF(K.EQ.NX*NY)THEN
                               CALL MSGDMP( 'W', 'TMSTLN', 
@@ -314,9 +320,6 @@
                               CALL MSGDMP( 'W', 'TMSTLN', 
      &                                     'ARRAY WILL BE OVER FLOW.')
                               GO TO 100
-                           ELSE  !* Ѱդۤή³ΰѤ
-                              TMPRX(1,2)=TMPX(NX*NY)
-                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
  164                    CONTINUE
                      END IF
@@ -385,6 +388,9 @@
                               ELSE
                                  GO TO 263  !* äƤеո׻.
                               END IF
+                           ELSE  !* Ѱդۤή³ΰѤ
+                              TMPRX(1,1)=TMPRX(NX*NY,1)
+                              TMPRY(1,1)=TMPRY(NX*NY,1)
                            END IF
 
                            IF(K.EQ.NX*NY)THEN
@@ -397,9 +403,6 @@
                               CALL MSGDMP( 'W', 'TMSTLN', 
      &                                     'ARRAY WILL BE OVER FLOW.')
                               GO TO 100
-                           ELSE  !* Ѱդۤή³ΰѤ
-                              TMPRX(1,1)=TMPRX(NX*NY,1)
-                              TMPRY(1,1)=TMPRY(NX*NY,1)
                            END IF
 
  262                    CONTINUE
@@ -458,6 +461,9 @@
 *-- ήѰդʾϢ³, ǽޤǷ׻.
                            IF(NM(ICOUNTER-1,2).LT.NX*NY)THEN
                               GO TO 260  !* äƤмή׻
+                           ELSE  !* Ѱդۤή³ΰѤ
+                              TMPRX(1,2)=TMPX(NX*NY)
+                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
                            IF(K.EQ.NX*NY)THEN
                               CALL MSGDMP( 'W', 'TMSTLN', 
@@ -468,9 +474,6 @@
                               CALL MSGDMP( 'W', 'TMSTLN', 
      &                                     'ARRAY WILL BE OVER FLOW.')
                               GO TO 100
-                           ELSE  !* Ѱդۤή³ΰѤ
-                              TMPRX(1,2)=TMPX(NX*NY)
-                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
  264                    CONTINUE
                      END IF
@@ -546,6 +549,9 @@
                                     GO TO 60  !* äƤмή׻ (ΰ趭)
                                  END IF
                               END IF
+                           ELSE  !* Ѱդۤή³ΰѤ
+                              TMPRX(1,2)=TMPX(NX*NY)
+                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
 
                            IF(K.EQ.NX*NY)THEN
@@ -558,9 +564,6 @@
                               CALL MSGDMP( 'W', 'TMSTLN', 
      &                                     'ARRAY WILL BE OVER FLOW.')
                               GO TO 100
-                           ELSE  !* Ѱդۤή³ΰѤ
-                              TMPRX(1,2)=TMPX(NX*NY)
-                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
 
  62                     CONTINUE
@@ -618,6 +621,9 @@
 *-- ήѰդʾϢ³, ǽޤǷ׻.
                            IF(NM(ICOUNTER-1,2).LT.NX*NY)THEN
                               GO TO 60  !* äƤмή׻
+                           ELSE  !* Ѱդۤή³ΰѤ
+                              TMPRX(1,2)=TMPX(NX*NY)
+                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
                            IF(K.EQ.NX*NY)THEN
                               CALL MSGDMP( 'W', 'TMSTLN', 
@@ -628,9 +634,6 @@
                               CALL MSGDMP( 'W', 'TMSTLN', 
      &                                     'ARRAY WILL BE OVER FLOW.')
                               GO TO 100
-                           ELSE  !* Ѱդۤή³ΰѤ
-                              TMPRX(1,2)=TMPX(NX*NY)
-                              TMPRY(1,2)=TMPY(NX*NY)
                            END IF
  64                     CONTINUE
                      END IF
