@@ -47,6 +47,7 @@
 *-- GETTING TMPACK'S PARAMETERS
       CALL TMRGET( 'ARRWINTV', ARROW_THRES )
       CALL TMLGET( 'NODRSHRT', NO_SHORT )
+      CALL TMLGET( 'ENDARROW', END_ARR )
 
       CALL GLRGET( 'RMISS', UNDEF )
       CALL GLLSET( 'LMISS', .TRUE. )
@@ -99,6 +100,9 @@
                IF(TRX(J,K).NE.UNDEF.AND.TRY(J,K).NE.UNDEF)THEN
                   TRX(J,K)=TRX(J,K)/RCOE
                   TRY(J,K)=TRY(J,K)/RCOE
+               ELSE
+                  TRX(J,K)=UNDEF
+                  TRY(J,K)=UNDEF
                END IF
  31         CONTINUE
  30      CONTINUE
